%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                         %
%    FINDZERO                                                             %
%                                                                         %
%    A MATLAB SCRIPT THAT SOLVES THE EQUATION $\mathbf{H}_T''=0$          %
%                                                                         %
%    REFERENCE: ANATOLIY MALYARENKO, YULIYA MISHURA, KONSTIANTYN          %
%    RALCHENKO, YEVHENIIYA ANASTASIIYA RUDYK. PROPERTIES OF VARIOUS       % 
%    ENTROPIES OF GAUSSIAN DISTRIBUTION AND COMPARISON OF ENTROPIES OF    % 
%    FRACTIONAL PROCESSES. AXIOMS 2023, 1, 0.                             % 
%                                                                         %
%    MATLAB VERSION: 9.7.0.1737446 (R2019b) UPDATE 9                      %
%                                                                         %
%    MATLAB LICENSE NUMBER: 1104639                                       %
%                                                                         %
%    COPYRIGHT (C) 2023 ANATOLIY MALYARENKO                               %
%                                                                         %
%    E-MAIL: ANATOLIY.MALYARENKO@MDU.SE                                   %                                                          
%                                                                         %
%    DATE: OCTOBER 25, 2023                                               %
%                                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% This program is free software: you can redistribute it and/or modify it 
% under the terms of the GNU General Public License as published by the 
% Free Software Foundation, either version 3 of the License, or (at your 
% option) any later version.

% This program is distributed in the hope that it will be useful, but 
% WITHOUT ANY WARRANTY; without even the implied warranty of 
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
% Public License for more details.

% You should have received a copy of the GNU General Public License along 
% with this program. If not, see <https://www.gnu.org/licenses/>.

function y = findzero(theta, x0)
y=fzero(@secondderivative,x0);
    % This function calculates the values of the second derivative
    function y=secondderivative(alpha)
       inte=log(theta)^2/sqrt(alpha)-log(theta)/(alpha*sqrt(alpha));
       inte=inte+3/(4*alpha^2*sqrt(alpha));
       inte=inte*theta^(alpha-1)*(alpha-1)^2/2;
       inte2=log(theta)/sqrt(alpha)-1/(2*alpha*sqrt(alpha));
       inte2=inte2*theta^(alpha-1)*(alpha-1);
       inte=inte-inte2+theta^(alpha-1)/sqrt(alpha);
       y=inte-1;
    end
end