%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                         %
%    INFLEXION                                                            %
%                                                                         %
%    A MATLAB SCRIPT THAT PRODUCES FIG.7                                  %
%                                                                         %
%    REFERENCE: ANATOLIY MALYARENKO, YULIYA MISHURA, KONSTIANTYN          %
%    RALCHENKO, YEVHENIIYA ANASTASIIYA RUDYK. PROPERTIES OF VARIOUS       % 
%    ENTROPIES OF GAUSSIAN DISTRIBUTION AND COMPARISON OF ENTROPIES OF    % 
%    FRACTIONAL PROCESSES. AXIOMS 2023, 1, 0.                             % 
%                                                                         %
%    MATLAB VERSION: 9.7.0.1737446 (R2019b) UPDATE 9                      %
%                                                                         %
%    MATLAB LICENSE NUMBER: 1104639                                       %
%                                                                         %
%    COPYRIGHT (C) 2023 ANATOLIY MALYARENKO                               %
%                                                                         %
%    E-MAIL: ANATOLIY.MALYARENKO@MDU.SE                                   %                                                          
%                                                                         %
%    DATE: OCTOBER 25, 2023                                               %
%                                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% This program is free software: you can redistribute it and/or modify it 
% under the terms of the GNU General Public License as published by the 
% Free Software Foundation, either version 3 of the License, or (at your 
% option) any later version.

% This program is distributed in the hope that it will be useful, but 
% WITHOUT ANY WARRANTY; without even the implied warranty of 
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
% Public License for more details.

% You should have received a copy of the GNU General Public License along 
% with this program. If not, see <https://www.gnu.org/licenses/>.

% Close all figures, if any
close all;
% To add equations to the graph
set(0,'defaultTextInterpreter','latex');
% The coefficients of the polynomial h(x) (p. 8)
p=[1 -1.5 2.25 -1.875];
r=roots(p);
% The real root of h(x)
x0=r(3);
% The possible values of theta
theta=1.5:0.01:4.5;
% The value which separates two cases in Remark 4
cv=x0./log(theta);
% Find the inflexion point of the function $\mathbf{H}_T(\alpha)$
infl=theta;
for i=1:length(theta)
    initial=cv(i);
    % In this interval, the initial value cv(i) is too close to the 
    % inflexion point
    % The Matlab function fzero cannot find the correct solution
    % Choose different initial value
    if (i>=130 && i<=137)
        initial=cv(129);
    end
    infl(i)=findzero(theta(i),initial);
end
% Draw the figure
figure;
plot(theta,cv,'-',theta,infl,'--','LineWidth',1.5);
xline(exp(x0),'LineWidth',1.5);
xlabel('$\theta$');
title('\bf $\nu(\theta)$ and inflexion points');
legend('\nu(\theta)','inflexion point');
grid;
% Save it to the file
print('fig7','-djpeg');