%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                         %
%    RATIO                                                                %
%                                                                         %
%    A MATLAB SCRIPT THAT PRODUCES FIG.9                                  %
%                                                                         %
%    REFERENCE: ANATOLIY MALYARENKO, YULIYA MISHURA, KONSTIANTYN          %
%    RALCHENKO, YEVHENIIYA ANASTASIIYA RUDYK. PROPERTIES OF VARIOUS       % 
%    ENTROPIES OF GAUSSIAN DISTRIBUTION AND COMPARISON OF ENTROPIES OF    % 
%    FRACTIONAL PROCESSES. AXIOMS 2023, 1, 0.                             % 
%                                                                         %
%    MATLAB VERSION: 9.7.0.1737446 (R2019b) UPDATE 9                      %
%                                                                         %
%    MATLAB LICENSE NUMBER: 1104639                                       %
%                                                                         %
%    COPYRIGHT (C) 2023 ANATOLIY MALYARENKO                               %
%                                                                         %
%    E-MAIL: ANATOLIY.MALYARENKO@MDU.SE                                   %                                                          
%                                                                         %
%    DATE: OCTOBER 25, 2023                                               %
%                                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% This program is free software: you can redistribute it and/or modify it 
% under the terms of the GNU General Public License as published by the 
% Free Software Foundation, either version 3 of the License, or (at your 
% option) any later version.

% This program is distributed in the hope that it will be useful, but 
% WITHOUT ANY WARRANTY; without even the implied warranty of 
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
% Public License for more details.

% You should have received a copy of the GNU General Public License along 
% with this program. If not, see <https://www.gnu.org/licenses/>.

% Close all figures, if any
close all;
% To add equations to the graph
set(0,'defaultTextInterpreter','latex');
% The possible values of the Hurst parameter
H=[0.2 0.4 0.6 0.8];
% The possible values of $\lambda$
lambda=0:0.01:20;
% Reserve memory
F1=zeros(length(H),length(lambda));
F2=zeros(length(H),length(lambda));
% Calculate C1, Equation (28)
for i=1:length(H)
    F1(i,:)=2*gamma(2*H(i))./((2*lambda).^(2*H(i)));
    F1(i,:)=F1(i,:)-2*gamma(H(i)+0.5)*besselk(H(i),lambda)./(sqrt(pi)*(2*lambda).^(H(i)));
end
% Calculate C2, Equation (29)
for i=1:length(H)
    F2(i,:)=(1-2*H(i))*gamma(H(i)+0.5)*gamma(H(i))*lambda.^(-2*H(i)).*(1-hypergeom([1 -0.5],[1-H(i) 0.5 1],lambda.^2/4))/sqrt(pi);
    F2(i,:)=F2(i,:)+gamma(1-H(i))*gamma(H(i)+0.5)*hypergeom([1 H(i)-0.5],[1 H(i)+1 H(i)+0.5],lambda.^2/4)./(sqrt(pi)*H(i)*2^(2*H(i)));
end
% Calculate ratio
F=sqrt(F1./F2);
% Draw the figure
figure;
plot(lambda,F(1,:), '-',lambda,F(2,:),'--',lambda,F(3,:),':',lambda,F(4,:),'-.','LineWidth',1.5);
set(gca,'FontWeight','bold');
xlabel('$\mathbf{\lambda}$');
ylabel('\bf Ratio');
title('\bf The ratio $\mathbf{C^I_1/C^H_1}$');
grid;
legend('H=0.2','H=0.4','H=0.6','H=0.8');
% Save it to the file
print('fig9','-djpeg');