%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                         %
%    TSALLIS1                                                             %
%                                                                         %
%    A MATLAB SCRIPT THAT PRODUCES FIG.2                                  %
%                                                                         %
%    REFERENCE: ANATOLIY MALYARENKO, YULIYA MISHURA, KONSTIANTYN          %
%    RALCHENKO, YEVHENIIYA ANASTASIIYA RUDYK. PROPERTIES OF VARIOUS       % 
%    ENTROPIES OF GAUSSIAN DISTRIBUTION AND COMPARISON OF ENTROPIES OF    % 
%    FRACTIONAL PROCESSES. AXIOMS 2023, 1, 0.                             % 
%                                                                         %
%    MATLAB VERSION: 9.7.0.1737446 (R2019b) UPDATE 9                      %
%                                                                         %
%    MATLAB LICENSE NUMBER: 1104639                                       %
%                                                                         %
%    COPYRIGHT (C) 2023 ANATOLIY MALYARENKO                               %
%                                                                         %
%    E-MAIL: ANATOLIY.MALYARENKO@MDU.SE                                   %                                                          
%                                                                         %
%    DATE: OCTOBER 25, 2023                                               %
%                                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


% This program is free software: you can redistribute it and/or modify it 
% under the terms of the GNU General Public License as published by the 
% Free Software Foundation, either version 3 of the License, or (at your 
% option) any later version.

% This program is distributed in the hope that it will be useful, but 
% WITHOUT ANY WARRANTY; without even the implied warranty of 
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
% Public License for more details.

% You should have received a copy of the GNU General Public License along 
% with this program. If not, see <https://www.gnu.org/licenses/>.

% Close all figures, if any
close all;
% To add equations to the graph
set(0,'defaultTextInterpreter','latex');
% The coefficients of the polynomial h(x) (p. 8)
p=[1 -1.5 2.25 -1.875];
r=roots(p);
% The real root of h(x)
x0=r(3);
% And its exponent
ex0=exp(x0);
% The possible values of theta
theta=[0.3 0.6 0.9];
% The possible values of alpha
alpha=0.01:0.01:0.5;
% The Tsallis entropy for the possible values of theta
H1=(theta(1).^(alpha-1)./sqrt(alpha)-1)./(1-alpha);
H2=(theta(2).^(alpha-1)./sqrt(alpha)-1)./(1-alpha);
H3=(theta(3).^(alpha-1)./sqrt(alpha)-1)./(1-alpha);
% Draw the figure
figure;
plot(alpha,H1,'-',alpha,H2,'-.',alpha,H3,'--','LineWidth',1.5);
xlabel('$\alpha$');
ylabel('$\mathbf{H}_T(\alpha)$');
title('The Tsallis entropy, $0<\theta<1$');
legend('\theta=0.3','\theta=0.6','\theta=0.9');
grid;
% Save it to the file
print('fig2','-djpeg');