%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                         %
%    TSALLIS3D2                                                           %
%                                                                         %
%    A MATLAB SCRIPT THAT PRODUCES FIG.3                                  %
%                                                                         %
%    REFERENCE: ANATOLIY MALYARENKO, YULIYA MISHURA, KONSTIANTYN          %
%    RALCHENKO, YEVHENIIYA ANASTASIIYA RUDYK. PROPERTIES OF VARIOUS       % 
%    ENTROPIES OF GAUSSIAN DISTRIBUTION AND COMPARISON OF ENTROPIES OF    % 
%    FRACTIONAL PROCESSES. AXIOMS 2023, 1, 0.                             % 
%                                                                         %
%    MATLAB VERSION: 9.7.0.1737446 (R2019b) UPDATE 9                      %
%                                                                         %
%    MATLAB LICENSE NUMBER: 1104639                                       %
%                                                                         %
%    COPYRIGHT (C) 2023 ANATOLIY MALYARENKO                               %
%                                                                         %
%    E-MAIL: ANATOLIY.MALYARENKO@MDU.SE                                   %                                                          
%                                                                         %
%    DATE: OCTOBER 25, 2023                                               %
%                                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% This program is free software: you can redistribute it and/or modify it 
% under the terms of the GNU General Public License as published by the 
% Free Software Foundation, either version 3 of the License, or (at your 
% option) any later version.

% This program is distributed in the hope that it will be useful, but 
% WITHOUT ANY WARRANTY; without even the implied warranty of 
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
% Public License for more details.

% You should have received a copy of the GNU General Public License along 
% with this program. If not, see <https://www.gnu.org/licenses/>.

% Close all figures, if any
close all
% To add equations to the graph
set(0,'defaultTextInterpreter','latex');
% Prepare the grid
[theta,alpha]=meshgrid(1:0.01:2.8,0:0.01:4);
% Calculate the Tsallis entropy
H=(theta.^(alpha-1)./sqrt(alpha)-1)./(1-alpha);
% Draw the figure
figure;
colormap hsv;
surf(theta,alpha,H,'FaceColor','interp','EdgeColor','none','FaceLighting','gouraud');
camlight right;
xlabel('$\theta$');
ylabel('$\alpha$');
zlabel('$\mathbf{H}_T(\theta,\alpha)$');
title('The Tsallis entropy, $1<\theta<\exp(x_0)$');
% Before saving to the file, rotate the figure using the mouse pointer
% to achieve the best view!